==> kinetophone-0.2.0.tar.gz: kinetophone-0.2.0/src/narrator/Kinetophone_narrator_config.hpp <==
// Kinetophone_narrator_config.hpp
//
// Copyright 2011-2012 Roan Trail, Inc.
//
// This file is part of Kinetophone.
//
// Kinetophone is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published
// by the Free Software Foundation, either version 2 of the License,
// or (at your option) any later version.
//
// Kinetophone is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.  You should have received
// a copy of the GNU General Public License along with Kinetophone. If
// not, see <http://www.gnu.org/licenses/>.

#ifndef KINETOPHONE_NARRATOR_CONFIG_HPP_
#define KINETOPHONE_NARRATOR_CONFIG_HPP_

#include <string>
#include <vector>

using std::string;
using std::vector;

namespace Roan_trail
{
  class Error;
  class Error_param;

  namespace Recorder
  {
    class Sound_recorder_config;
  }

  using Roan_trail::Recorder::Sound_recorder_config;

  namespace Kinetophone
  {
    // Helper struct to store narrator application settings.
    // It is a struct instead of a class since it primarily only
    // aggregates various data
    struct Kinetophone_narrator_config
    {
    public:
      // constructor/destructor/copy
      Kinetophone_narrator_config();
      Kinetophone_narrator_config(const Kinetophone_narrator_config& config);
      Kinetophone_narrator_config& operator=(const Kinetophone_narrator_config& config);
      virtual ~Kinetophone_narrator_config();
      // typedef
      // structure members
      string help_message;
      string image_directory;
      string session_file_path;
      struct Level_meter_struct
      {
        Level_meter_struct();
        bool model_ballistics;
        int attack_period; // milliseconds
        int decay_period; // milliseconds
        int peak_hold_period; // milliseconds
      } level_meter;
      int update_rate;
      bool show_file_size;
      bool show_audio_info;
      bool show_overflow_count;
      bool detailed_error;
      string custom_installation_dir;
      Sound_recorder_config* sound_recorder_config;
      // defaults
      static const int default_update_rate;
      // command class constants
      static const int command_error          = 0;
      static const int command_narrate        = 1;
      static const int command_help           = 2;
      static const int command_list_devices   = 3;
      static const int command_output_version = 4;
      //
      int parse_program_options(int argc,
                                const char** argv,
                                Error_param& return_error);
    };
  }
}

#endif // KINETOPHONE_NARRATOR_CONFIG_HPP_

==> kinetophone-0.3.0.tar.gz: kinetophone-0.3.0/src/narrator/Kinetophone_narrator_config.hpp <==
// Kinetophone_narrator_config.hpp
//
// Copyright 2011-2012 Roan Trail, Inc.
//
// This file is part of Kinetophone.
//
// Kinetophone is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published
// by the Free Software Foundation, either version 2 of the License,
// or (at your option) any later version.
//
// Kinetophone is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.  You should have received
// a copy of the GNU General Public License along with Kinetophone. If
// not, see <http://www.gnu.org/licenses/>.

#ifndef KINETOPHONE_NARRATOR_CONFIG_HPP_
#define KINETOPHONE_NARRATOR_CONFIG_HPP_

#include <string>

namespace Roan_trail
{
  class Error_param;

  namespace Recorder
  {
    class Sound_recorder_config;
  }

  namespace Kinetophone
  {
    // Helper struct to store narrator application settings.
    // It is a struct instead of a class since it primarily only
    // aggregates various data
    struct Kinetophone_narrator_config
    {
    public:
      // constructor/destructor/copy
      Kinetophone_narrator_config();
      Kinetophone_narrator_config(const Kinetophone_narrator_config& config);
      Kinetophone_narrator_config& operator=(const Kinetophone_narrator_config& config);
      virtual ~Kinetophone_narrator_config();
      // typedef
      // structure members
      std::string help_message;
      std::string image_directory;
      std::string session_file_path;
      struct Level_meter_struct
      {
        Level_meter_struct();
        bool model_ballistics;
        int attack_period; // milliseconds
        int decay_period; // milliseconds
        int peak_hold_period; // milliseconds
      } level_meter;
      int update_rate;
      bool show_file_size;
      bool show_audio_info;
      bool show_overflow_count;
      bool detailed_error;
      std::string custom_installation_dir;
      Roan_trail::Recorder::Sound_recorder_config* sound_recorder_config;
      // defaults
      static const int default_update_rate;
      // command class constants
      static const int command_error          = 0;
      static const int command_narrate        = 1;
      static const int command_help           = 2;
      static const int command_list_devices   = 3;
      static const int command_output_version = 4;
      //
      int parse_program_options(int argc,
                                const char** argv,
                                Error_param& return_error);
    };
  }
}

#endif // KINETOPHONE_NARRATOR_CONFIG_HPP_
